@@ -25,8 +25,10 @@
  *		Bug fixes for SVR4
  *	07/23/93	3.3.0	patchlevel 23
  *		New baseline release
+ *	08/23/93	3.3.1	patchlevel 24
+ *		Bug fixes for SunOS 4.1.1
  */
 
 #define	RELEASE		3
-#define	PATCHLEVEL	23
-#define	VERSION		"3.3.0"
+#define	PATCHLEVEL	24
+#define	VERSION		"3.3.1"
