@@ -13,7 +13,7 @@
  */
 
 #ifndef lint
-static	char	sccsid[] = "@(#)useradd.c	3.13	07:59:56	06 May 1993";
+static	char	sccsid[] = "@(#)useradd.c	3.14	08:20:53	23 Aug 1993";
 #endif
 
 #include "config.h"
@@ -745,9 +745,9 @@ set_defaults ()
 #endif
 	if (! out_shell)
 #ifdef	SVR4
-		fprintf (ofp, "defshell=%d\n", def_shell);
+		fprintf (ofp, "defshell=%s\n", def_shell);
 #else
-		fprintf (ofp, "SHELL=%d\n", def_shell);
+		fprintf (ofp, "SHELL=%s\n", def_shell);
 #endif
 	if (! out_skel)
 #ifdef	SVR4
@@ -860,15 +860,26 @@ char	*list;
 			fprintf (stderr, "%s: unknown group %s\n", Prog, list);
 			errors++;
 		}
+		list = cp;
 
+#ifdef	USE_NIS
+		/*
+		 * Don't add this group if they are an NIS group.  Tell
+		 * the user to go to the server for this group.
+		 */
+
+		if (__isgrNIS ()) {
+			fprintf (stderr, "%s: group `%s' is a NIS group.\n",
+				Prog, grp->gr_name);
+			continue;
+		}
+#endif
 		/*
 		 * Add the GID value from the group file to the user's
 		 * list of groups.
 		 */
 
 		user_groups[user_ngroups++] = grp->gr_gid;
-
-		list = cp;
 	} while (list);
 
 	/*
@@ -967,7 +978,9 @@ struct	passwd	*pwent;
 	pwent->pw_uid = user_id;
 	pwent->pw_gid = user_gid;
 	pwent->pw_gecos = user_comment;
+#ifdef	ATT_COMMENT
 	pwent->pw_comment = "";
+#endif
 	pwent->pw_dir = user_home;
 	pwent->pw_shell = user_shell;
 }
@@ -1349,7 +1362,7 @@ char	**argv;
 					def_expire = strtoday (optarg);
 				else {
 #ifdef	SHADOWPWD
-					user_expire = strtoday (optarg);
+					user_expire = atoi (optarg);
 #ifdef	ITI_AGING
 					user_expire *= DAY;
 #endif
@@ -1414,6 +1427,7 @@ char	**argv;
 				}
 				sflg++;
 				strncpy (user_shell, optarg, BUFSIZ);
+				strncpy (def_shell, user_shell, BUFSIZ);
 				break;
 			case 'u':
 				uflg++;
